@@ -125,7 +125,7 @@ class HeatControl:
 
         # Create table if it does not exist
         cur.execute(
-            "CREATE TABLE IF NOT EXISTS hour_prices (DateTime DATETIME,  Hour INTEGER, PriceNoTax REAL, Rank INTEGER, powerlevel CHAR(10), UNIQUE(DateTime, Hour) ON CONFLICT REPLACE)"
+            "CREATE TABLE IF NOT EXISTS hour_prices (DateTime DATETIME,  Hour INTEGER, PriceWithTax Real, PriceNoTax REAL, Rank INTEGER, powerlevel CHAR(10), UNIQUE(DateTime, Hour) ON CONFLICT REPLACE)"
         )
 
         # Print hour prices
@@ -144,21 +144,22 @@ class HeatControl:
             ).date()
 
             cur.execute(
-                "INSERT INTO hour_prices (DateTime, Hour, PriceNoTax, Rank, powerlevel) VALUES (?,?,?,?,?)",
+                "INSERT INTO hour_prices (DateTime, Hour, PriceWithTax, PriceNoTax, Rank, powerlevel) VALUES (?,?,?,?,?,?)",
                 (
                     date,
                     hour["Hour"],
+                    hour["PriceWithTax"],
                     hour["PriceNoTax"],
                     hour["Rank"],
                     powerlevel,
                 ),
             )
 
-            print(str(hour["Hour"]) + " " + str(hour["PriceNoTax"]) + " " + powerlevel)
+            print(str(hour["Hour"]) + " " + str(hour["PriceWithTax"]) + " " + powerlevel)
 
         con.commit()
         con.close()
-
+        
     def initialize_gpio(self):
         GPIO.cleanup()
         GPIO.setmode(GPIO.BCM)
@@ -226,31 +227,23 @@ class HeatControl:
 
                 if consecutive_hours <= MAX_CONSECUTIVE_ZERO_POWER_HOURS:
                     add_to_zero_power_hours = True
-                else:
-                    print(
-                        f"Consecutive hours {consecutive_hours} is above max consecutive hours {MAX_CONSECUTIVE_ZERO_POWER_HOURS}. Not adding {hour['Hour']} to ZeroPowerHours"
-                    )
 
             # Add to ZeroPowerHours always if price is above ultimate max price
             if hour["PriceWithTax"] > ULTIMATE_HIGHEST_PRICE:
-                print(f"Price {hour['PriceWithTax']} is above ultimate max price")
                 add_to_zero_power_hours = True
 
             # Keep heating on if price is below ultimate min price
             if hour["PriceWithTax"] < ULTIMATE_LOWEST_PRICE:
-                print(f"Price {hour['PriceWithTax']} is below ultimate min price")
                 continue
 
             if add_to_zero_power_hours:
 
                 # Don't add more than SAFE_ZERO_POWER_HOURS
                 if len(self.ZeroPowerHours) < SAFE_ZERO_POWER_HOURS:
-                    print(f"Adding {hour['Hour']} to ZeroPowerHours")
                     self.ZeroPowerHours.append(hour)
                 add_to_zero_power_hours = False
 
             elif len(self.HalfPowerHours) < HALF_POWER_HOURS:
-                print(f"Adding {hour['Hour']} to HalfPowerHours")
                 self.HalfPowerHours.append(hour)
 
     def set_heat(self):
